==> jc-1.4.0.tar.gz: javax/print/event/PrintEvent.h <==
// public class javax.print.event.PrintEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_print_event_PrintEvent_H_
#define _JC_javax_print_event_PrintEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_event_PrintEvent$sub_refs	_jc_javax_print_event_PrintEvent$sub_refs;
typedef struct _jc_javax_print_event_PrintEvent$sub_nonrefs	_jc_javax_print_event_PrintEvent$sub_nonrefs;
typedef struct _jc_javax_print_event_PrintEvent$refs	_jc_javax_print_event_PrintEvent$refs;
typedef struct _jc_javax_print_event_PrintEvent$nonrefs	_jc_javax_print_event_PrintEvent$nonrefs;
typedef struct _jc_javax_print_event_PrintEvent$object	_jc_javax_print_event_PrintEvent$object;

typedef const struct _jc_javax_print_event_PrintEvent$vmethods	_jc_javax_print_event_PrintEvent$vmethods;
typedef const struct _jc_javax_print_event_PrintEvent$vtable	_jc_javax_print_event_PrintEvent$vtable;
typedef const struct _jc_javax_print_event_PrintEvent$vtype	_jc_javax_print_event_PrintEvent$vtype;

// Constructors
extern void _jc_javax_print_event_PrintEvent$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_javax_print_event_PrintEvent$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_event_PrintEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_event_PrintEvent$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_event_PrintEvent$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_event_PrintEvent$object *);
};

// Vtable
struct _jc_javax_print_event_PrintEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_print_event_PrintEvent$vmethods	javax_print_event_PrintEvent;
};

// Vtype
struct _jc_javax_print_event_PrintEvent$vtype {
	_jc_type			type;
	_jc_javax_print_event_PrintEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_event_PrintEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_event_PrintEvent$refs {
    _jc_javax_print_event_PrintEvent$sub_refs	javax_print_event_PrintEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_event_PrintEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_event_PrintEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_print_event_PrintEvent$sub_nonrefs	javax_print_event_PrintEvent;
};

// Object instance structure
struct _jc_javax_print_event_PrintEvent$object {
	_jc_javax_print_event_PrintEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_event_PrintEvent$vtype	*vtype;
	_jc_javax_print_event_PrintEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_event_PrintEvent$vtype _jc_javax_print_event_PrintEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_event_PrintEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_event_PrintEvent$class_object;

#endif	/* _JC_javax_print_event_PrintEvent_H_ */

==> jc-1.4.6.tar.gz: javax/print/event/PrintEvent.h <==
// public class javax.print.event.PrintEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_print_event_PrintEvent_H_
#define _JC_javax_print_event_PrintEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_event_PrintEvent$sub_refs	_jc_javax_print_event_PrintEvent$sub_refs;
typedef struct _jc_javax_print_event_PrintEvent$sub_nonrefs	_jc_javax_print_event_PrintEvent$sub_nonrefs;
typedef struct _jc_javax_print_event_PrintEvent$refs	_jc_javax_print_event_PrintEvent$refs;
typedef struct _jc_javax_print_event_PrintEvent$nonrefs	_jc_javax_print_event_PrintEvent$nonrefs;
typedef struct _jc_javax_print_event_PrintEvent$object	_jc_javax_print_event_PrintEvent$object;

typedef const struct _jc_javax_print_event_PrintEvent$vmethods	_jc_javax_print_event_PrintEvent$vmethods;
typedef const struct _jc_javax_print_event_PrintEvent$vtable	_jc_javax_print_event_PrintEvent$vtable;
typedef const struct _jc_javax_print_event_PrintEvent$vtype	_jc_javax_print_event_PrintEvent$vtype;

// Constructors
extern void _jc_javax_print_event_PrintEvent$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_javax_print_event_PrintEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_event_PrintEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_event_PrintEvent$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_event_PrintEvent$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_event_PrintEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_event_PrintEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_print_event_PrintEvent$vmethods	javax_print_event_PrintEvent;
};

// Vtype
struct _jc_javax_print_event_PrintEvent$vtype {
	_jc_type			type;
	_jc_javax_print_event_PrintEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_event_PrintEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_event_PrintEvent$refs {
    _jc_javax_print_event_PrintEvent$sub_refs	javax_print_event_PrintEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_event_PrintEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_event_PrintEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_print_event_PrintEvent$sub_nonrefs	javax_print_event_PrintEvent;
};

// Object instance structure
struct _jc_javax_print_event_PrintEvent$object {
	_jc_javax_print_event_PrintEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_event_PrintEvent$vtype	*vtype;
	_jc_javax_print_event_PrintEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_event_PrintEvent$vtype _jc_javax_print_event_PrintEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_event_PrintEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_event_PrintEvent$class_object;

#endif	/* _JC_javax_print_event_PrintEvent_H_ */
